<?php
/*
 * Version 1.101: Verifica si es multisite para insertar campo country
 * ARTURO: Codigo para la Creacion de un custom type para ABM de paypals
 * 1 Creación del usuario supervisor
 * 2 Si tiene privilegio 'ver_paypals' registra un new_post_type
 * 2.1 Agrega los meta boxes para el Custom Post Type Paypal *Por paises
 * 2.2 Genera el contenido que hay que mostrar dentro del meta box *Por paises
 * 2.3 Graba los campos del formulario del meta box *Por paises
 * 2.4 Personalizar columnas
 * 2.5 Definir el contenido a mostrar en las columnas
 * 2.6 Columnas ordenables
 * 2.7 Añade metadatos (en inputs) al Quick edit
 * 2.8 Añade un input select en la fila de filtros del listado CPT
 * 2.9 El mecanismo del filtro (the ‘parse_query’ filter)
 * 3 Agregar un listener para paypal checkout
 * 4 Crear un shortcode 'paypals' 
 * 5 Crear un template para el tipo de pagina paypals (Si no existe)
 * 6 Crear una page 'listapaypals' (Si no existe)
 */

defined( 'ABSPATH' ) || exit;

	$GLOBALS['user_email_name']='liveAPIUsername';
	$GLOBALS['_user_email_name']='_liveAPIUsername';
	$GLOBALS['paypal_cpt']='paypals';
	$GLOBALS['info_paypal_field']='woocommerce_ppec_paypal_settings';
	$GLOBALS['paypalinputname']='woocommerce_ppec_paypal_api_username';
	$GLOBALS['user_in_settings']='api_username';

/**
 * 1.- Creación del usuario supervision por una sola vez
 */

function usuariopaypal()
{
	if(get_role("shop_supervisor") !== null){
		add_role( 'shop_supervisor', 'Shop Supervisor', get_role( 'shop_manager' )->capabilities);
		$admin = get_role('administrator');
		$admin->add_cap('ver_paypals');
	}
	if(!username_exists('supervision'))
	{
		$user_id = wp_create_user( 'supervision', 'Supervision.2021*', 'supervision@windowsandoffice.com' );
		$user = new WP_User( $user_id );
		$user->set_role( 'shop_supervisor' );
	}
	if(!username_exists('despacho'))
	{
		$user_id = wp_create_user( 'despacho', 'Despacho.2021*', 'despacho@windowsandoffice.com' );
		$user = new WP_User( $user_id );
		$user->set_role( 'shop_manager' );
	}
	$user = wp_get_current_user();
	$role = $user->roles;

}//fin de funcion usuariopaypal

add_action( 'admin_init', 'usuariopaypal' );

/**
 * 2.- Si tiene privilegio 'ver_paypals' registra un new_post_type
 */

add_action('init', 'register_new_post_type');

function register_new_post_type()
{
	if(current_user_can('ver_paypals')){
		$args = array(
			'public' => true,
			'labels' => array(
			'name' => 'Paypals',
			'singular_name' => 'Paypal',
			'all_items' => 'Todos los Paypals',
			'add_new' => 'Agregar nuevo Paypal',
			'add_new_item' => 'Agregar nuevo Paypal',
			'edit_item' => 'Editar Paypal',
			'new_item' => 'Nuevo Paypal',
			'view_item' => 'Ver Paypal',
			'search_items' => 'Buscar Paypals',
			'not_found' => 'No se han encontrado Paypals',
			'not_found_in_trash' => 'No se han encontrado Paypals en la Papelera'
			),
		 'supports' => array( 'title' )
		);

		register_post_type('Paypals', $args);
	}//fin de si es admin
}//fin de funcion
	
/**
 * 2.1.- Llama funcion para agregar los los meta boxes para el Custom Post Type Paypal
 * https://developer.wordpress.org/reference/functions/add_meta_box/
 */

function paypal_register_meta_boxes()
{
    add_meta_box('Paypal-Parameters', 'Parametros', 'paypal_output_meta_box', 'Paypals', 'normal', 'high');
}

/**
 * 2.2 Inputs para cada nuevo campo personalizado (dentro del meta box)
 */
function paypal_output_meta_box($post)
{
    // Los campos se graban en la base de datos con un subrayado bajo como prefijo
    // WP indica así por defecto que son campos metas
	//cambiar aqui
    $liveAPIUsername = get_post_meta($post->ID, '_liveAPIUsername', true);
    $liveAPIPassword = get_post_meta($post->ID, '_liveAPIPassword', true);
    $liveAPISignature = get_post_meta($post->ID, '_liveAPISignature', true);

    $ppcategory = get_post_meta($post->ID, '_ppcategory', true);
    $ppdaysales = get_post_meta($post->ID, '_ppdaysales', true);
    $pplifetimesales = get_post_meta($post->ID, '_pplifetimesales', true);
    $ppstatus = get_post_meta($post->ID, '_ppstatus', true);
    $forsites = get_post_meta($post->ID, '_forsites', true);

    //$ppactivesales = get_post_meta($post->ID, '_ppactivesales', true);
    //$ppmonthsales = get_post_meta($post->ID, '_ppmonthsales', true);
    $ppmonthlimit = get_post_meta($post->ID, '_ppmonthlimit', true);

	echo "<div style='float:left;width:48%;'>";
    wp_nonce_field( 'graba_paypal', 'paypal_nonce' );
    echo('<label for="liveAPIUsername">' . __('Live API Username: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPIUsername" id="liveAPIUsername" style="width:300px;margin-left:10px;" value="' . esc_attr($liveAPIUsername) . '"><br><br>');
    
    echo('<label for="liveAPIPassword">' . __('Live API Password: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPIPassword" id="liveAPIPassword" style="width:300px;margin-left:16px;" value="' . esc_attr($liveAPIPassword) . '"><br><br>');
    
    echo('<label for="liveAPISignature">' . __('Live API Signature: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPISignature" id="liveAPISignature" style="width:300px;margin-left:18px;" value="' . esc_attr($liveAPISignature) . '"><br><br>');

	echo "<div style='padding-bottom:20px;'>";
		echo('<label for="ppcategory" style="padding-right:67px;">' . __('Category: ', 'pluginwao') . '</label>');
		$checked = $ppcategory=="r"?"checked":"";
		echo '<span style="border-radius:5px;background-color:red;padding:5px;margin-right:5px;"><input type="radio" id="ppcategory" name="ppcategory" value="r" '.$checked.'><label for="ppcategory" style="color:blue;">Red</label></span>'; 
		$checked = $ppcategory=="y"?"checked":"";
		echo '<span style="border-radius:5px;background-color:yellow;padding:5px;margin-right:5px;"><input type="radio" id="ppcategory" name="ppcategory" value="y" '.$checked.'><label for="ppcategory" style="color:blue;">Yellow</label></span>'; 
		$checked = $ppcategory=="g"?"checked":"";
		echo '<span style="border-radius:5px;background-color:green;padding:5px;margin-right:5px;"><input type="radio" id="ppcategory" name="ppcategory" value="g" '.$checked.'><label for="ppcategory" style="color:white;">Green</label></span>'; 
	echo "</div>";
	if(is_multisite()){
		$sites = get_sites();
		echo('<label for="forsites">' . __('Sites: ', 'pluginwao') . '</label>');
		echo '<select style="margin-left:95px;width:300px;" name="forsites[]" id="forsites" multiple size="12">';
		foreach ( $sites as $site ) {
			switch_to_blog( $site->blog_id );
			//$opt = get_option( '_invoices_options' );
			if($forsites<>FALSE){
				$sel=in_array($site->blog_id,$forsites)?"selected":"";
			}//if forsites false END
			echo "<option value='".$site->blog_id."' ".$sel." >".$site->blogname."</option>";
		}//fin de foreach
		echo "</select>";	
		restore_current_blog();
	}//fin de is_multisite
	//echo('<div style="margin-top:15px;"><label for="ppdaysales">' . __('Paypal Day Sales: ', 'pluginwao') . '</label>');
	//echo('<input type="text" name="ppdaysales" id="ppdaysales" style="width:300px;margin-left:30px;" value="' . esc_attr($ppdaysales) . '"><br><br></div>');
	//echo('<div style="margin-top:5px;"><label for="pplifetimesales">' . __('Paypal Lifetime Sales: ', 'pluginwao') . '</label>');
	//echo('<input type="text" name="pplifetimesales" id="pplifetimesales" style="width:300px;margin-left:5px;" value="' . esc_attr($pplifetimesales) . '"><br><br></div>');

	echo "</div>";
	echo "<div style='float:right;width:48%;text-align:left;'>";

	echo('<div style="margin-top:25px;"><label for="ppmonthlimit">' . __('Monthly Limit: ', 'pluginwao') . '</label>');
	echo('<input type="text" name="ppmonthlimit" id="ppmonthlimit" style="width:300px;margin-left:43px;" value="' . esc_attr($ppmonthlimit) . '"><br><br></div>');

	echo('<div style="margin-top:15px;"><label for="ppstatus">' . __('Paypal Status: ', 'pluginwao') . '</label>'); 
	echo('<select name="ppstatus" id="ppstatus" style="width:300px;margin-left:45px;" >');
		$selected=$ppstatus=="Activo"?'selected':'';
		if($selected=='selected'){
			echo('<option value="Activo" '.$selected.'>Activo</option>');
		}else{
			$selected=$ppstatus=="Reserva"?'selected':'';
			echo('<option value="Reserva" '.$selected.'>Reserva</option>');
			$selected=$ppstatus=="En_revision"?'selected':'';
			echo('<option value="En_revision" '.$selected.'>En revision</option>');
		}
	echo('</select><br><br></div>');
	echo "</div>";
		
	echo "<div style='clear:both'></div>";

}
add_action('add_meta_boxes', 'paypal_register_meta_boxes');

/**
 * 2.3 Graba los campos del formulario del meta box
 * @param int $post_id Post ID
 */

function paypal_save_meta_boxes($post_id)
{
    // Comprueba que el nonce es correcto para evitar ataques CSRF
    if ( !isset($_POST['paypal_nonce']) || ! wp_verify_nonce( $_POST['paypal_nonce'], 'graba_paypal') ) {
		if ( ! wp_verify_nonce( $_POST[ '_inline_edit' ], 'inlineeditnonce' ) ) {
			return;
		}else{
			$ppstatus = sanitize_text_field($_POST['ppstatus']);
			update_post_meta($post_id, '_ppstatus', $ppstatus);
			return;
		}
        return $post_id;
    }
    // Comprueba que el tipo de post es paypal
    if ($GLOBALS['paypal_cpt'] != $_POST['post_type']) {
        return $post_id;
    }

    // Comprueba que el usuario actual tiene permiso para editar esto
    if (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    // Ahora puedes grabar los datos con tranquilidad
    // Observa que cuando vienen del formulario los campos meta no vienen con el prefijo subrayado bajo pero cuando los grabas en el post hay que poner el prefijo, igual que cuando los leías del post
	// cambiar aqui
    $liveAPIUsername = sanitize_text_field($_POST['liveAPIUsername']);
    update_post_meta($post_id, '_liveAPIUsername', $liveAPIUsername);
    $liveAPIPassword = sanitize_text_field($_POST['liveAPIPassword']);
    update_post_meta($post_id, '_liveAPIPassword', $liveAPIPassword);
    $liveAPISignature = sanitize_text_field($_POST['liveAPISignature']);
    update_post_meta($post_id, '_liveAPISignature', $liveAPISignature);
    $ppcategory = sanitize_text_field($_POST['ppcategory']);
    update_post_meta($post_id, '_ppcategory', $ppcategory);
	if(is_multisite()){
		$forsites = $_POST['forsites'];
		update_post_meta($post_id, '_forsites', $forsites);
	}
    $ppdaysales = sanitize_text_field($_POST['ppdaysales']);
    if(!empty($ppdaysales)){
		update_post_meta($post_id, '_ppdaysales', $ppdaysales);
	} 
	$pplifetimesalessales = sanitize_text_field($_POST['pplifetimesales']);
    if(!empty($pplifetimesales)){
		update_post_meta($post_id, '_pplifetimesales', $pplifetimesalessales);
	}
    $ppstatus = sanitize_text_field($_POST['ppstatus']);
    update_post_meta($post_id, '_ppstatus', $ppstatus);

    $ppmonthlimit = sanitize_text_field($_POST['ppmonthlimit']);
    update_post_meta($post_id, '_ppmonthlimit', $ppmonthlimit);
    return true;
}

add_action('save_post', 'paypal_save_meta_boxes');

/**
 * 2.4 Aumentar columnas personalizadas en la tabla
 */

function personalizar_columnas1( $columns ) 
{
	if(is_multisite()){
		$columns1 = array(
		  'username' => __( 'User Name', 'paypals' ),
		  'countries' => __( 'Countries', 'paypals' ),
		  'ppdaysales' => __( 'Paypal Sales', 'paypals' ),
		  'ppstatus' => __( 'Paypal Status', 'paypals' ),
		  'ppactiveinsites' => __( 'Active in sites', 'paypals' )
		);
	}else{
		$columns1 = array(
		  'username' => __( 'User Name', 'paypals' ),
		  'ppdaysales' => __( 'Paypal Sales', 'paypals' ),
		  'ppstatus' => __( 'Paypal Status', 'paypals' ),
		  'ppactiveinsites' => __( 'Active in sites', 'paypals' )
		);
	}

	$columns=array_merge($columns, $columns1);
  return $columns;
}//function personalizar columna END

add_filter( 'manage_paypals_posts_columns', 'personalizar_columnas1');

function admin_style1() 
{
echo "<style>.column-username {width:300px;} .column-primary {width:300px;}</style>";
}
add_action('admin_enqueue_scripts', 'admin_style1');


/**
 * 2.5 Definir el contenido a mostrar en las columnas
 */

function personalizar_contenidos1( $column, $post_id ) 
{
  $info = get_post_meta($post_id);
  $info1 = get_post($post_id);
  switch ($column)
  {
	case 'username':
		$color=paypal_color_span($info['_ppcategory'][0]);
		echo $color.$info[$GLOBALS['_user_email_name']][0];
	  break;
	case 'countries':
		$blog_id = get_current_blog_id();
		$sites=get_post_meta($post_id,'_forsites');
		$salida="";
		if(!empty($sites[0])){
			foreach($sites[0] as $site){
				switch_to_blog( $site);
				$optblogname = get_option( 'blogname' );
				$salida.="<span style='background-color:azure;border:solid gray 1px;border-radius:3px;font-size:10px;margin-left:3px;padding:0px 3px 0px 3px'>".$optblogname."</span>";
				restore_current_blog();
			}
		}//if sites false END
		echo $salida;
	  break;
	case 'ppactiveinsites':
		$blog_id = get_current_blog_id();
		$sites=get_post_meta($post_id,'_ppactiveinsites');
		$salida="";
		if(!empty($sites[0])){
			foreach($sites[0] as $site){
				switch_to_blog( $site);
				$optblogname = get_option( 'blogname' );
				$salida.="<span style='background-color:PaleGreen;border:solid gray 1px;border-radius:3px;font-size:10px;margin-left:3px;padding:0px 3px 0px 3px'>".$optblogname."</span>";
				restore_current_blog();
			}
		}//if sites false END
		echo $salida; 
	  break;
	case 'ppdaysales':
		echo $info['_ppdaysales'][0];
	  break;
	case 'pplifetimesalesxxx':
		echo $info['_pplifetimesales'][0];
	  break;
	case 'ppstatus':
		echo $info['_ppstatus'][0];
	  break;
  }
}//function personalizar contenidos END

add_action( 'manage_paypals_posts_custom_column', 'personalizar_contenidos1', 10, 2);

/**
 * 2.6 Columnas ordenables
 * Tres funciones: keys_sortable_columns, keys_load, my_sort_keys
 */
// Nombra la columna que sera ordenable
function keys_sortable_columns( $columns ) 
{
 $columns['ppstatus'] = 'Paypal Status';
 return $columns;
}//function keys sortable columns END

add_filter( 'manage_edit-paypals_sortable_columns', 'keys_sortable_columns' );

/* Only run our customization on the 'edit.php' page in the admin. */
// En edit.php pone el mecanismo de ordenacion
function keys_load() 
{
 add_filter( 'request', 'my_sort_keys');
}//function keys load END 

/* Sorts  paypals. */
function my_sort_keys( $vars ) 
{
	/* Check if we're viewing the 'paypals' post type. */
	if ( isset( $vars['post_type'] ) && 'paypals' == $vars['post_type'] ) {
		/* Check if 'orderby' is set to 'ppstatus'. */
		if ( isset( $vars['orderby'] ) && 'ppstatus' == $vars['orderby'] ) {
			/* Merge the query vars with our custom variables. */
			$vars = array_merge(
			$vars,
			array(
				 'meta_key' => '_ppstatus',
				 'orderby' => '_ppstatus'
				)
				//meta_value_num
			);
		}
	}
 return $vars; 
}//function my sort keys END		

add_action( 'load-edit.php', 'keys_load');

/**
 * 2.7 Añade metadatos (en inputs) al Quick edit
 * https://rudrastyh.com/wordpress/quick-edit-tutorial.html
 */

function paypals_quick_edit_fields( $column_name, $post_type ) 
{
	switch( $column_name ) {
		case 'ppstatus': 
			$ppstatus = get_post_meta($post->ID, '_ppstatus', true);
			?>
				<fieldset class="inline-edit-col-left">
					<div class="inline-edit-col-ps">
						<label>
							<span class="title">Papal Status</span>
							<select name="ppstatus" id="ppstatussel">
								<?php $selected=$ppstatus=='Activo'?'selected':'';?>
								<option id="Activo" value="Activo" <?php echo $selected;?> >Activo</option>
								<?php $selected=$ppstatus=='Reserva'?'selected':'';?>
								<option id="Reserva" value="Reserva" <?php echo $selected;?> >Reserva</option>
								<?php $selected=$ppstatus=='En_revision'?'selected':'';?>
								<option id="En_revision" value="En_revision" <?php echo $selected;?>>En_revision</option>
							</select>
						</label>
					</div>
				</fieldset>
<script>
jQuery( function( $ ){
	const wp_inline_edit_function = inlineEditPost.edit;
	// we overwrite the it with our own
	inlineEditPost.edit = function( post_id ) {
		// let's merge arguments of the original function
		wp_inline_edit_function.apply( this, arguments );
		// get the post ID from the argument
		if ( typeof( post_id ) == 'object' ) { // if it is object, get the ID number
			post_id = parseInt( this.getId( post_id ) );
		}
		// add rows to variables
		const edit_row = $( '#edit-' + post_id )
		const post_row = $( '#post-' + post_id )
		const ppstatus = $( '.column-ppstatus', post_row ).text()
		// populate the inputs with column data
		if(ppstatus!='Activo'){
			$('#ppstatussel').empty()
			.append('<option value="Reserva">Reserva</option>')
			.append('<option value="En_revision">En revision</option>')
			;
		}
		$('div.inline-edit-col-ps select').val(ppstatus).change();
	}
});
</script>
				<?php
			break;
	}
}

add_action( 'quick_edit_custom_box',  'paypals_quick_edit_fields', 10, 2 );

/**
 * 2.8 Añade un input select en la fila de filtros del listado CPT
 */

	function ppstatus_filtering($post_type)
	{
		if($GLOBALS['paypal_cpt'] !== $post_type){
		  return; //filter your post
		}
		$selected = '';
		$request_attr = 'paypal_status';
		if ( isset($_REQUEST[$request_attr]) ) {
		  $selected = $_REQUEST[$request_attr];
		}
		//get unique values of the meta field to filer by.
		$meta_key = '_ppstatus';
		global $wpdb;
		
		$result = $wpdb->get_results( 
			$wpdb->prepare( "SELECT DISTINCT meta_value FROM {$wpdb->prefix}postmeta WHERE meta_key = '_ppstatus'" 
			) 
		);
	   //build a  custom dropdown list of values to filter by
		echo '<select id="paypal_status" name="paypal_status">';
		echo '<option value="0">' . __( 'Show all status', 'paypals' ) . ' </option>';
		foreach($result as $location){
		  //$select = ($org->ID == $selected) ? ' selected="selected"':'';
		  $select = ($location->meta_value == $selected) ? ' selected="selected"':'';
		  echo '<option value="'.$location->meta_value.'"'.$select.'>' . $location->meta_value . ' </option>';
		}
		echo '</select>';
	  }

	add_action('restrict_manage_posts','ppstatus_filtering');

/**
 * 2.9 El mecanismo del filtro (the ‘parse_query’ filter)
 */

	function ppstatus_filter_request_query($query)
	{
		//modify the query only if it admin and main query.
		//if( !(is_admin() AND $query->is_main_query()) ){ 
		if( $query->is_main_query() ){ 
		  //return $query;
		}

		//we want to modify the query for the targeted custom post and filter option
		if( !($GLOBALS['paypal_cpt'] === $query->query['post_type'] AND isset($_REQUEST['paypal_status']) ) ){
		  return $query;
		}
		//for the default value of our filter no modification is required
		if(0 == $_REQUEST['paypal_status']){
		  //return $query;
		}

		//List posts this user is "tagged" in (B).
		$query->set('meta_key', '_ppstatus');
		$query->set('meta_value', $_REQUEST['paypal_status']);
		$query->set('meta_compare', 'LIKE');
		//die;
		return $query;
	  }

	add_filter( 'parse_query', 'ppstatus_filter_request_query');


/*3.- Agregar un listener para paypal checkout*/

function mi_script() 
{
	$opt = get_option( '_invoices_options' );
	$subd=$opt{'subdirectorio'};
	$ruta=$_SERVER['HTTP_HOST'].$subd.get_blog_details()->path;
    echo '
    <script type="text/javascript">
	//*woocommerce_ppec_paypal_api_username* es el nombre y id del input que al hacer clic abrirá una ventana emergente vinculada desde donde se seleccionará el paypal.
	var el = document.getElementById("'.$GLOBALS['paypalinputname'].'");
	el.addEventListener("click", (event) => {
	    //listapaypals es el permalink de una pagina que se debe crear y añadir el shortcode [paypals]
	    //La pagina debe ser configurada con un template de ancho completo, si no existiere, crear uno en wp-content/themes/nombredeltema/page-templates/nombretemplate.php
			window.open("https://'.$ruta.'listapaypals", "Seleccionar paypals", 
"toolbar=0,scrollbars=0,location=0,statusbar=0,menubar=0,resizable=1,width=700,height=400,left = 890,top = 500");
	    }
	);
    </script>';
}

add_action( 'admin_footer', 'mi_script' );

/*4.- Crear un shortcode 'paypals'*/

function funcion_paypals() 
{
	if(current_user_can('ver_paypals')){
		//Obtenemos el total de paypals
		global $wpdb;
		$q="SELECT COUNT(ID) FROM {$wpdb->prefix}posts WHERE post_status='publish' AND post_type='".$GLOBALS['paypal_cpt']."'";
		$total=$wpdb->get_var($q);
		$args = array(
			'posts_per_page'   => $total,
			'offset'           => 0,
			'category'         => '',
			'orderby'          => 'post_title',
			'order'            => 'ASC',
			'post_type'        => $GLOBALS['paypal_cpt'],
			'post_status'      => 'publish',
			'suppress_filters' => true,
			'meta_query' => array(
				array(
					'key' => '_ppstatus',
					'value' => 'En_revision',
					'compare' => '!=',
				)
			)			
		); 
		$paypls = get_posts($args);

		$tabla.="<style>
			table, th, td {
			  border: 1px solid gray;
			  border-collapse:collapse;
			}
			table input {border:none;background-color:transparent!important;}
		}</style>";
		$tabla.="<h3 style='text-align:center;'>SELECCIONE UN PAYPAL.</h3>";
		$tabla.="<table class='wp-list-table striped' align='center' width='550px'>";
		$tabla.="<tr>";
			$tabla.="<td align='center' width='20px' style='width:20px;'>NR.</td>";
			$tabla.="<td align='center' width='280px'>PAYPAL NAME</td>";
			$tabla.="<td align='center' width='30px'>STATUS</td>";
		$tabla.="</tr>";
		$scripts="";
		$scripts.="
		elemento = window.opener.document.getElementById('newusername');
		if (!elemento){
			var ObjetoInicial = window.opener.document.getElementById('woocommerce_ppec_paypal_api_credentials').innerHTML;//Leer valor 
			let ObjetoMedio = ObjetoInicial.replace('</h3>', '');
			let NuevoInput = '<input type=".'"'."hidden".'"'." id = ".'"'."newusername".'"'." name = ".'"'."newusername".'"'." value=".'"nothing"'."></h3>'
			let ObjetoFinal = ObjetoMedio + NuevoInput;
			window.opener.document.getElementById('woocommerce_ppec_paypal_api_credentials').innerHTML = ObjetoFinal;//Asignar valor 
		}
		";
		$i=1;
		foreach ($paypls as $paypl){
			$id =$paypl->ID;
			$print_tr=FALSE;
			if(!is_multisite()){//si no es multisite, mostrar todos los paypals
				$print_tr=TRUE;
			}else{
				$blog_id = get_current_blog_id();
				$sites=get_post_meta($id,'_forsites');
				if (!empty($sites[0])){//si es multisite filtramos por pais
					if(in_array($blog_id,$sites[0])){
						$print_tr=TRUE;
					}//if in array blog id END
				}
			}//fin de is multisite. Permite filtrar 
			if($print_tr){
				//modificar aqui
				$liveAPIUsername=get_post_meta($id,'_liveAPIUsername');
				$liveAPIPassword=get_post_meta($id,'_liveAPIPassword');
				$liveAPISignature=get_post_meta($id,'_liveAPISignature');
				$ppcategory=get_post_meta($id,'_ppcategory');
				$ppdaysales=get_post_meta($id,'_ppdaysales');
				$pplifetimesales=get_post_meta($id,'_pplifetimesales');
				$ppstatus=get_post_meta($id,'_ppstatus');
				//modificar aqui
				$APIUsername=$liveAPIUsername[0];
				$APIPassword=$liveAPIPassword[0];
				$APISignature=$liveAPISignature[0];
				$tabla.="<tr>";
					$tabla.="<td align='center' width='20px' style='width:20px;' ><input style='border:none;width:25px;' readonly value='".$i++."'></td>";
					$tabla.="<td width='280px'>".paypal_color_span($ppcategory[0])."&nbsp;<input id='in_".$id."' name='in_".$id."' style='border:none;' readonly value='".$paypl->post_title."'></td>";
					$tabla.="<td width='30px'><input style='width:60px;border:none;' id='in_".$id."' name='amount_".$id."' readonly value='".$ppstatus[0]."'></td>";
				$tabla.="</tr>";
				//modificar aqui
				$scripts.="var el = document.getElementById('in_".$id."');
					el.addEventListener('click', (event) => {
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_username').value='".$APIUsername."';//TextBox1 is in parent page
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_password').value='".$APIPassword."';//TextBox1 is in parent page
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_signature').value='".$APISignature."';//TextBox1 is in parent page
					window.opener.document.getElementById('newusername').value='".$APIUsername."';//TextBox1 is in parent page

					window.close();
					},true
					);";
				
			}//fin de si print_tr
		}//foreach paypls END
		$tabla.="</table>";
		$tabla.= "<script type='text/javascript'>";
		$tabla.=$scripts;
		$tabla.= "</script>";
		$tabla.="<div id = 'alcargar' onload='creainput()'>.";
		$tabla.="</div>";
		return $tabla;
	}else{
		return '<meta http-equiv="refresh" content="2;URL=/shop">';
	}
}
add_shortcode('paypals','funcion_paypals');

/*5.- Crear un template para el tipo de pagina paypals (Si no existe)*/

function paypal_page_template()
{
	$file1=get_stylesheet_directory()."/paypals_template.php";
	//unlink($file1);
	if(!file_exists($file1)){
	//echo "ruta : ".$file1;
		//$texto = "UN TEXTO X";
		$texto = '<'.'?'.'php'.PHP_EOL;
		$texto .= '/**'.PHP_EOL;
		$texto .= ' * Temp'.'late Name: Paypals Template 1'.PHP_EOL;
		$texto .= ' *'.PHP_EOL;
		$texto .= ' * Displays the Paypals Table page template.'.PHP_EOL;
		$texto .= ' *'.PHP_EOL;
		$texto .= ' */'.PHP_EOL;
		$texto .= '?>'.PHP_EOL;
		$texto .= '<html>'.PHP_EOL;
		$texto .= '<head>'.PHP_EOL;
		$texto .= '<meta name="robots" content="noindex,nofollow">'.PHP_EOL;
		$texto .= '<link rel="stylesheet" href="'.site_url().'/wp-admin/load-styles.php?c=0&amp;dir=ltr&amp;load%5Bchunk_0%5D=dashicons,admin-bar,wp-pointer,buttons,media-views,common,forms,admin-menu,dashboard,list-tables,edit,revisions,media,themes,abo&amp;load%5Bchunk_1%5D=ut,nav-menus,widgets,site-icon,l10n,wp-auth-check,wp-components,wp-jquery-ui-dialog&amp;ver=5.8.2" type="text/css" media="all" />'.PHP_EOL;
		$texto .= '</head>'.PHP_EOL;
		$texto .= '<body>'.PHP_EOL;
		$texto .= '<div class="wrap">'.PHP_EOL;
		$texto .= '	<div id="primary" class="content-area">'.PHP_EOL;
		$texto .= '			<'.'?'.'php '.PHP_EOL;
		$texto .= '			the_content();'.PHP_EOL;
		$texto .= '			?'.'>'.PHP_EOL;
		$texto .= '	</div>'.PHP_EOL;
		$texto .= '</body>'.PHP_EOL;
		$texto .= '</html>'.PHP_EOL;

		$file1_p=fopen($file1,'w');
		fwrite($file1_p, $texto);
		fclose($file1_p);

	}
	
}//fin de funcion template
add_action( 'admin_init', 'paypal_page_template' );


/*6.- Crear una page 'listapaypals' (Si no existe)*/
function lista_paypals_page()
{
//	global $wpdb;
//	$my_posts = $wpdb->get_row( 'SELECT ID FROM {$wpdb->prefix}posts WHERE post_title  = "listapaypals" AND post_status="publish"');
	$args = array(
		'post_type' =>	'page',
		'title'	=> 'listapaypals'
	);
	//	'status'	=> 'publish'
	$my_posts = get_posts( $args );
	if(empty($my_posts))
	{
		$parametros=array(
		'ID'=>'',
		'post_author'=>$user->ID,
		'post_content'=>'[paypals]',
		'post_title'=>'listapaypals',
		'post_name'=>'listapaypals',
		'post_status'=>'publish',
		'post_type'=>'page'
		);
		$post_id = wp_insert_post($parametros);
		add_post_meta($post_id, '_wp_page_template', 'paypals_template.php', true);
	}// Fin de empty
	
}

add_action( 'admin_init', 'lista_paypals_page' );

include("paypal-common-functions.php");

/*FIN DE: Codigo para la Creacion de un custom type para ABM de paypals*/

/*
* PAGINA DE CONFIGURACION DE PARAMETROS PARA WAO LICENSE MANAGER
*/


// Agrega un submenú de configuración
// PARAMETROS: 
// add_submenu_page( string $parent_slug, string $page_title, string $menu_title, 
// string $capability, string $menu_slug, callable $callback = '', int|float $position = null ):string|false
function paypal_submenu(){
//		add_dashboard_page(
// La funcion wao_settings_page se encuentra fuera de la clase. :(
	add_submenu_page(
		'edit.php?post_type=paypals',
		__( 'WLM Settings', 'paypals' ),
		__( 'WLM Settings', 'paypals' ),
		'manage_options',
		'PAYPALsettings',
		'paypal_settings_page'
	);
}
add_action( 'admin_menu', 'paypal_submenu');
	
function paypal_settings_page(){
	?>
	<form action="options.php" method="post">
		<?php 
		settings_fields( '_paypal_options' ); //Llamamos a la seccion de configuracion definida con register_setting()
		do_settings_sections( 'paypal_fields' ); //Mostramos la sección definida con add_settings_section
		?>
		<input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e( 'Save' ); ?>" />
		<hr>
  </form>
	<?php
} // function wao_settings_page() END


  //////REGISTRANDO LOS CAMPOS O VARIABLES EN LA BASE DE DATOS [PASO 1]

  function paypal_register_settings() {
	
	// REGISTRAMOS UNA PAGINA DE CONFIGURACION
	//register_setting( string  $option_group , string  $ option_name , array  $args  =  array()  )
    register_setting( '_paypal_options', '_paypal_options', '_paypal_options_validate' );

	// CREAMOS UNA SECCION DENTRO LA PAGINA DE CONFIGURACION
    // add_settings_section( cadena  $id , cadena  $título , $devolución de llamada invocable  , cadena $página , matriz $argumentos  =  matriz()  )  
	// Muestre las secciones de configuración en la función de devolución de llamada de su página de administración con do_settings_sections() .
	// Agregue campos de configuración a su sección con add_settings_field() . 
	add_settings_section( 'paypal1_settings', 'Paypals manager Settings', 'paypals_section_text', 'paypal_fields' );

	// INSERTAMOS CADA INPUT, MEDIANTE UNA FUNCION EXTERNA.
	// add_settings_field( string $id, string $title, callable $callback, string $page, string $section = 'default', array $args = array() )
	// Un add_settings_field asociado a una settings_secction por cada campo de configuración.
	// Por cada uno, hay una función separada para insertar un input.
     add_settings_field( 'paypal_setting_main_url', 'URL de la administraci&oacute; central de paypals', 'paypal_setting_main_url', 'paypal_fields', 'paypal1_settings' );
	  
  }
  add_action( 'admin_init', 'paypal_register_settings' );

  /////VALIDACION

  function _paypal_options_validate( $input ) {
      $newinput['urlmanuals'] = trim( $input['urlmanuals'] );
      if ( ! preg_match( '/^[a-z0-9]{32}$/i', $newinput['urlmanuals'] ) ) {
          $newinput['urlmanuals'] = '';
      }
      //return $newinput;
      return $input;
  }

  //////////LOS CAMPOS DEL FORMULARIO, LOS QUE SE VEN [PASO 2]
  function paypals_section_text() {
      echo '<p>Configuracion de Parametros para Paypals.</p>';
  }

  function paypal_setting_main_url() { // Combos (COMBO#SKU|ID*ID)
      $options = get_option( '_paypal_options' );
      echo "<input id='waolm_urlmanuals' name='_paypal_options[urlmanuals]' type='text' style='width:400px;'; value='".esc_attr( $options['urlmanuals'] )."' /><i style='margin-left:20px;'>(Incluir <b>https://</b> y un slash al final.)</i> ";
  }





